@@ -162,7 +162,7 @@ fn merklize_inner(
 
         (MerkleNode::from_engine(engine), 1)
     } else {
-        let div = len / 2 + len % 2;
+        let div = ext_len / 2 + ext_len % 2;
 
         let (node1, height1) = merklize_inner(
             engine_proto,
@@ -177,7 +177,7 @@ fn merklize_inner(
             engine_proto,
             iter,
             depth + 1,
-            len % 2 == 1,
+            ext_len % 2 == 1,
             Some(empty_node),
         );
 
